<?php
/*
	Plugin Name: ChatterBot2WP
	Plugin URI: https://chatterbot2wp.com/
	Description: Adds your ChatterPal Campaign Code to your WordPress site.
	Tags: chatterpal, chatbot, chatterbot, chatterbot2wp
	Author: Thor Hammaraxx
	Author URI: https://thorhammaraxx.com/
	Donate link: https://thorhammaraxx.com/donate/
	Requires at least: 4.1
	Tested up to: 6.2.2
	Stable tag: 20230616
	Version: 1.22
	Requires PHP: 5.2
	Text Domain: chatterbot2wp
	License: GPL v2 or later
*/

/*
	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version
	2 of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	with this program. If not, visit: https://www.gnu.org/licenses/

	Copyright 2019 Thor Hammaraxx. All rights reserved.
*/
require __DIR__ . '/plugin-update-checker-4.6/plugin-update-checker.php';
$myUpdateChecker = Puc_v4_Factory::buildUpdateChecker(
	'https://chatterbot2wp.com/free_chatterbot2wp_plugins/chatterbot2wp/1/plugin.json',
	__FILE__ //, //Full path to the main plugin file or functions.php.
	//'chatterbot2wp'
);
if (!defined('ABSPATH')) die();
if (!class_exists('ChatterBot2WP')) {
	class ChatterBot2WP {
		function __construct() {
			$this->constants();
			$this->includes();
			add_action('admin_menu',            array($this, 'add_menu'));
			add_filter('admin_init',            array($this, 'add_settings'));
			add_action('admin_enqueue_scripts', array($this, 'admin_scripts'));
			add_filter('plugin_action_links',   array($this, 'action_links'), 10, 2);
			add_action('admin_init',            array($this, 'check_version'));
			add_action('admin_init',            array($this, 'reset_options'));
			add_action('admin_notices',         array($this, 'admin_notices'));
		}
		function constants() {
			if (!defined('C2W_VERSION')) define('C2W_VERSION', '1.20');
			if (!defined('C2W_REQUIRE')) define('C2W_REQUIRE', '4.1');
			if (!defined('C2W_AUTHOR'))  define('C2W_AUTHOR',  'Thor Hammaraxx');
			if (!defined('C2W_NAME'))    define('C2W_NAME',    __('ChatterBot2WP', 'chatterbot2wp'));
			if (!defined('C2W_HOME'))    define('C2W_HOME',    'https://chatterbot2wp.com/');
			if (!defined('C2W_PATH'))    define('C2W_PATH',    'options-general.php?page=chatterbot2wp');
			if (!defined('C2W_URL'))     define('C2W_URL',     plugin_dir_url(__FILE__));
			if (!defined('C2W_DIR'))     define('C2W_DIR',     plugin_dir_path(__FILE__));
			if (!defined('C2W_FILE'))    define('C2W_FILE',    plugin_basename(__FILE__));
			if (!defined('C2W_SLUG'))    define('C2W_SLUG',    basename(dirname(__FILE__)));
		}
		function includes() {
			require_once C2W_DIR .'inc/plugin-core.php';
		}
		function add_menu() {
			$title_page = esc_html__('ChatterBot2WP', 'chatterbot2wp');
			$title_menu = esc_html__('ChatterBot2WP',    'chatterbot2wp');
			add_options_page($title_page, $title_menu, 'manage_options', 'chatterbot2wp', array($this, 'display_settings'));
		}
		function add_settings() {
			register_setting('c2w_plugin_options', 'c2w_options', array($this, 'validate_settings'));
		}
		function admin_scripts($hook) {
			if ($hook === 'settings_page_chatterbot2wp') {
				wp_enqueue_style('chatterbot2wp', C2W_URL .'css/settings.css', array(), C2W_VERSION);
				wp_enqueue_script('chatterbot2wp', C2W_URL .'js/settings.js', array('jquery'), C2W_VERSION);
				$this->localize_scripts();
			}
		}
		function localize_scripts() {
			$script = array(
				'confirm_message' => esc_html__('Are you sure you want to restore all default options?', 'chatterbot2wp')
			);
			wp_localize_script('chatterbot2wp', 'chatterbot2wp', $script);
		}
		function action_links($links, $file) {
			if ($file === C2W_FILE) {
				$c2w_links = '<a href="'. admin_url(C2W_PATH) .'">'. esc_html__('Settings', 'chatterbot2wp') .'</a>';
				array_unshift($links, $c2w_links);
			}
			return $links;
		}
		function check_version() {
			$wp_version = get_bloginfo('version');
			if (isset($_GET['activate']) && $_GET['activate'] == 'true') {
				if (version_compare($wp_version, C2W_REQUIRE, '<')) {
					if (is_plugin_active(C2W_FILE)) {
						deactivate_plugins(C2W_FILE);
						$msg  = '<strong>'. C2W_NAME .'</strong> '. esc_html__('requires WordPress ', 'chatterbot2wp') . C2W_REQUIRE;
						$msg .= esc_html__(' or higher, and has been deactivated! ', 'chatterbot2wp');
						$msg .= esc_html__('Please return to the', 'chatterbot2wp') .' <a href="'. admin_url() .'">';
						$msg .= esc_html__('WP Admin Area', 'chatterbot2wp') .'</a> '. esc_html__('to upgrade WordPress and try again.', 'chatterbot2wp');
						wp_die($msg);
					}
				}
			}
		}
		function admin_notices() {
			$screen = get_current_screen();
			if (!property_exists($screen, 'id')) return;
			if ($screen->id === 'settings_page_chatterbot2wp') {
				if (isset($_GET['c2w-reset-options'])) {
					if ($_GET['c2w-reset-options'] === 'true') : ?>
						<div class="notice notice-success is-dismissible"><p><strong><?php esc_html_e('Default options restored.', 'chatterbot2wp'); ?></strong></p></div>
					<?php else : ?>
						<div class="notice notice-info is-dismissible"><p><strong><?php esc_html_e('No changes made to options.', 'chatterbot2wp'); ?></strong></p></div>
					<?php endif;
				}
			}
		}
		function reset_options() {
			if (isset($_GET['c2w-reset-options']) && wp_verify_nonce($_GET['c2w-reset-options'], 'c2w_reset_options')) {
				if (!current_user_can('manage_options')) exit;
				$update = update_option('c2w_options', $this->default_options());
				$result = $update ? 'true' : 'false';
				$location = add_query_arg(array('c2w-reset-options' => $result), admin_url(C2W_PATH));
				wp_redirect(esc_url_raw($location));
				exit;
			}
		}
		function __clone() {
			_doing_it_wrong(__FUNCTION__, esc_html__('Cheatin&rsquo; huh?', 'chatterbot2wp'), C2W_VERSION);
		}
		function __wakeup() {
			_doing_it_wrong(__FUNCTION__, esc_html__('Cheatin&rsquo; huh?', 'chatterbot2wp'), C2W_VERSION);
		}
		function default_options() {
			$options = array(
				'cpc_id'          => 'qaxNf3P5mrqD',
				'c2w_location'    => 'footer',
				'c2w_display_campaign' => 0,
				'admin_area'      => 1,
				'disable_admin'   => 0,
				'c2w_show_on_home'=> 1,
				'c2w_all_pages'   => 0,
				'c2w_pages_array' => '',
				'version_alert'   => 0,
				'default_options' => 0
			);
			return apply_filters('c2w_default_options', $options);
		}
		function validate_settings($input) {
			$input['cpc_id'] = wp_filter_nohtml_kses($input['cpc_id']);
			if (!isset($input['c2w_pages_array'])){
				$input['c2w_pages_array'] = '';
			}else{
				$input['c2w_pages_array'] = str_replace(' ','',$input['c2w_pages_array']);
			}
			if (!isset($input['c2w_location'])) $input['c2w_location'] = null;
			if (!array_key_exists($input['c2w_location'], $this->options_locations())) $input['c2w_location'] = null;
			if (!isset($input['c2w_display_campaign'])) $input['c2w_display_campaign'] = null;
			$input['c2w_display_campaign'] = ($input['c2w_display_campaign'] == 1 ? 1 : 0);
			if (!isset($input['admin_area'])) $input['admin_area'] = null;
			$input['admin_area'] = ($input['admin_area'] == 0 ? 0 : 1);
			if (!isset($input['c2w_show_on_home'])) $input['c2w_show_on_home'] = null;
			$input['c2w_show_on_home'] = ($input['c2w_show_on_home'] == 1 ? 1 : 0);
			if (!isset($input['disable_admin'])) $input['disable_admin'] = null;
			$input['disable_admin'] = ($input['disable_admin'] == 1 ? 1 : 0);
			if (!isset($input['c2w_all_pages'])) $input['c2w_all_pages'] = null;
			$input['c2w_all_pages'] = ($input['c2w_all_pages'] == 1 ? 1 : 0);
			return $input;
		}
		function options_locations() {
			return array(
				'header' => array(
					'value' => 'header',
					'label' => esc_html__('Include campaign code in page head (via', 'chatterbot2wp') .' <code>wp_head</code>'. esc_html__(')', 'chatterbot2wp')
				),
				'footer' => array(
					'value' => 'footer',
					'label' => esc_html__('Include campaign code in page footer (via', 'chatterbot2wp') .' <code>wp_footer</code>'. esc_html__(')', 'chatterbot2wp')
				)
			);
		}
		function display_settings() {
			$c2w_options = get_option('c2w_options', $this->default_options());
			require_once C2W_DIR .'inc/settings-display.php';
		}
		function select_menu($items, $menu) {
			$options = get_option('c2w_options', $this->default_options());
			$output = '';
			foreach ($items as $item) {
				$key = isset($options[$menu]) ? $options[$menu] : '';
				$value = isset($item['value']) ? $item['value'] : '';
				$checked = ($value == $key) ? ' checked="checked"' : '';
				$output .= '<div class="c2w-radio-inputs'. esc_attr($class) .'">';
				$output .= '<input type="radio" name="c2w_options['. esc_attr($menu) .']" value="'. esc_attr($item['value']) .'"'. $checked .'> ';
				$output .= '<span>'. $item['label'] .'</span>'; //
				$output .= '</div>';
			}
			return $output;
		}
		function callback_reset() {
			$nonce = wp_create_nonce('c2w_reset_options');
			$href  = add_query_arg(array('c2w-reset-options' => $nonce), admin_url(C2W_PATH));
			$label = esc_html__('Restore default plugin options', 'chatterbot2wp');
			return '<a class="c2w-reset-options" href="'. esc_url($href) .'">'. esc_html($label) .'</a>';
		}
	}
	$GLOBALS['ChatterBot2WP'] = $ChatterBot2WP = new ChatterBot2WP();
	chatterbot2wp_init($ChatterBot2WP);
}
?>
